@@ -9,17 +9,13 @@ from concurrent.futures import ThreadPoolExecutor
 from itertools import repeat
 from looker_deployer.utils import deploy_logging
 from looker_deployer.utils import parse_ini
-from looker_sdk import client, models
+from looker_deployer.utils.get_client import get_client
+from looker_sdk import models
 
 
 logger = deploy_logging.get_logger(__name__)
 
 
-def get_client(ini, env):
-    sdk = client.setup(config_file=ini, section=env)
-    return sdk
-
-
 def get_space_ids_from_name(space_name, parent_id, sdk):
     if (space_name == "Shared" and parent_id == "0"):
         return ["1"]
@@ -41,7 +37,7 @@ def create_or_return_space(space_name, parent_id, sdk):
             raise e
         else:
             logger.warning("No folders found. Creating folder now")
-            new_space = models.Space(name=space_name, parent_id=parent_id)
+            new_space = models.CreateSpace(name=space_name, parent_id=parent_id)
             res = sdk.create_space(new_space)
             return res.id
 
@@ -60,7 +56,7 @@ def get_gzr_creds(ini, env):
     return (host, client_id, client_secret, verify_ssl)
 
 
-def export_spaces(env, ini, path):
+def export_spaces(env, ini, path, debug=False):
     host, client_id, client_secret, verify_ssl = get_gzr_creds(ini, env)
 
     gzr_command = [
@@ -81,11 +77,13 @@ def export_spaces(env, ini, path):
     # config parser returns a string - easier to parse that than convert to a bool
     if verify_ssl == "False":
         gzr_command.append("--no-verify-ssl")
+    if debug:
+        gzr_command.append("--debug")
 
     subprocess.run(gzr_command)
 
 
-def import_content(content_type, content_json, space_id, env, ini):
+def import_content(content_type, content_json, space_id, env, ini, debug=False):
     assert content_type in ["dashboard", "look"], "Unsupported Content Type"
     host, client_id, client_secret, verify_ssl = get_gzr_creds(ini, env)
 
@@ -119,6 +117,8 @@ def import_content(content_type, content_json, space_id, env, ini):
     # config parser returns a string - easier to parse that than convert to a bool
     if verify_ssl == "False":
         gzr_command.append("--no-verify-ssl")
+    if debug:
+        gzr_command.append("--debug")
 
     subprocess.run(gzr_command)
 
@@ -144,7 +144,7 @@ def build_spaces(spaces, sdk):
     return id_tracker[0]
 
 
-def deploy_space(s, sdk, env, ini, recursive):
+def deploy_space(s, sdk, env, ini, recursive, debug=False):
 
     logger.debug("working folder", extra={"working_folder": s})
 
@@ -177,7 +177,8 @@ def deploy_space(s, sdk, env, ini, recursive):
             look_files,
             repeat(space_id),
             repeat(env),
-            repeat(ini)
+            repeat(ini),
+            repeat(debug)
         )
     # deploy dashboards
     logger.debug("running dashboards", extra={"dashboards": dash_files})
@@ -188,19 +189,20 @@ def deploy_space(s, sdk, env, ini, recursive):
             dash_files,
             repeat(space_id),
             repeat(env),
-            repeat(ini)
+            repeat(ini),
+            repeat(debug)
         )
 
     # go for recursion
     if recursive and space_children:
         logger.info("Attemting Recursion of children folders", extra={"children_folders": space_children})
         for child in space_children:
-            deploy_space(child, sdk, env, ini, recursive)
+            deploy_space(child, sdk, env, ini, recursive, debug)
     else:
         logger.info("No Recursion specified or empty child list", extra={"children_folders": space_children})
 
 
-def deploy_content(content_type, content, sdk, env, ini):
+def deploy_content(content_type, content, sdk, env, ini, debug=False):
     # extract directory path
     dirs = content.rpartition(os.sep)[0] + os.sep
 
@@ -214,11 +216,11 @@ def deploy_content(content_type, content, sdk, env, ini):
     # The final value of id_tracker in build_spaces must be the targeted space id
     space_id = build_spaces(spaces_to_process, sdk)
 
-    import_content(content_type, content, space_id, env, ini)
+    import_content(content_type, content, space_id, env, ini, debug)
 
 
 def send_content(
-    sdk, env, ini, target_folder=None, spaces=None, dashboards=None, looks=None, recursive=False
+    sdk, env, ini, target_folder=None, spaces=None, dashboards=None, looks=None, recursive=False, debug=False
 ):
 
     if spaces:
@@ -236,10 +238,10 @@ def send_content(
                     # copy the source space directory tree to target space override
                     shutil.copytree(s, updated_space)
                     # kick off the job from the new space
-                    deploy_space(updated_space, sdk, env, ini, recursive)
+                    deploy_space(updated_space, sdk, env, ini, recursive, debug)
             # If no target space override, kick off job normally
             else:
-                deploy_space(s, sdk, env, ini, recursive)
+                deploy_space(s, sdk, env, ini, recursive, debug)
     if dashboards:
         logger.debug("Deploying dashboards", extra={"dashboards": dashboards})
         for dash in dashboards:
@@ -256,9 +258,9 @@ def send_content(
                     shutil.copy(dash, target_dir)
                     new_dash_path = [os.path.join(target_dir, f) for f in os.listdir(target_dir)][0]
                     # kick off the job from the new space
-                    deploy_content("dashboard", new_dash_path, sdk, env, ini)
+                    deploy_content("dashboard", new_dash_path, sdk, env, ini, debug)
             else:
-                deploy_content("dashboard", dash, sdk, env, ini)
+                deploy_content("dashboard", dash, sdk, env, ini, debug)
     if looks:
         logger.debug("Deploying looks", extra={"looks": looks})
         for look in looks:
@@ -275,9 +277,9 @@ def send_content(
                     shutil.copy(look, target_dir)
                     new_look_path = [os.path.join(target_dir, f) for f in os.listdir(target_dir)][0]
                     # kick off the job from the new space
-                    deploy_content("look", new_look_path, sdk, env, ini)
+                    deploy_content("look", new_look_path, sdk, env, ini, debug)
             else:
-                deploy_content("look", look, sdk, env, ini)
+                deploy_content("look", look, sdk, env, ini, debug)
 
 
 def main(args):
@@ -296,7 +298,7 @@ def main(args):
 
     if args.export:
         logger.info("Pulling content from dev", extra={"env": args.env, "pull_location": args.export})
-        export_spaces(args.env, args.ini, args.export)
+        export_spaces(args.env, args.ini, args.export, args.debug)
     else:
         sdk = get_client(args.ini, args.env)
         send_content(
@@ -307,5 +309,6 @@ def main(args):
             args.folders,
             args.dashboards,
             args.looks,
-            args.recursive
+            args.recursive,
+            args.debug
         )
